PyTorch interface
====================

This module provides the PyTorch implementation of the Rigid Body Dynamics algorithms.

.. tip::

   For the batched version of the algorithms, see :mod:`adam.pytorch.computation_batch`.

----------------

.. currentmodule:: adam.pytorch

.. automodule:: adam.pytorch.computations
   :members:
   :undoc-members:
   :show-inheritance:
